package kccf.res.service;

import java.util.List;

import cmm.service.CmmAmsAssetMediaVO;
import cmm.service.CmmCouncilInfoVO;
import cmm.util.DataMap;
import egovframework.rte.fdl.cmmn.exception.EgovBizException;

public interface ResourcesService {

    int selectResourcesListTotCnt(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
    int selectResourcesListSchTotCnt(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
    int selectResourcesListProvideTotCnt() throws EgovBizException;
    int selectResourcesListOpenTotCnt(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
    List<CmmAmsAssetMediaVO> selectResourcesList(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;    
    List<DataMap> selectCouncilList() throws EgovBizException;    
    
    CmmCouncilInfoVO selectCouncilInfo(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException; 
    List<DataMap> selectCouMainBannerList(DataMap param) throws EgovBizException;
    List<DataMap> selectCouMainResTagList(DataMap param) throws EgovBizException;
    List<CmmAmsAssetMediaVO> selectCouMainSeeResList(DataMap param) throws EgovBizException;
    List<CmmAmsAssetMediaVO> selectCouMainRecommendResList(DataMap param) throws EgovBizException;
    List<DataMap> selectCouMainBestYearList(DataMap param) throws EgovBizException;
    List<CmmAmsAssetMediaVO> selectCouMainYearDataList(DataMap param) throws EgovBizException;
    
    
    
    int selectResourcesCouListTotCnt(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
    int selectResourcesCouListSchTotCnt(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
    List<CmmAmsAssetMediaVO> selectResourcesCouList(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
    

    
    
//	CmmAmsAssetMediaVO selectResourcesDetail(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;    
//    List<CmmCmsKeywordsVO> selectResourcesKeywordsList(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
//    List<CmmCmsTagsVO> selectResourcesTagsList(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
//	List<CmmCmsVO> selectResourcesThemeList(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
//	List<CmmCmsVO> selectResourcesAddrList(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
//	List<CmmCouncilInfoVO> selectResourcesCouncilList(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
//	List<CmmCmsUserGroupVO> selectResourcesUserGroupList(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
//    List<DataMap> selectResourcesRelatedThemeList(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
//    List<DataMap> selectResourcesRelatedLibraryList(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
//    List<CmmnDetailCode> selectResourcesFilter(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
//    List<CmmnDetailCode> selectResourcesFilterCnt(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
//    List<CmmCouncilInfoVO> selectResourcesCouncilFilter(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
//    List<CmmCouncilInfoVO> selectResourcesCouncilFilterCnt(CmmAmsAssetMediaVO cmmAmsAssetMediaVO) throws EgovBizException;
        
}
